@@ -1,6 +1,5 @@
-from commmons.hash import md5
+from commmons import md5, head
 from lxml.html import HtmlElement
-from commmons import head
 
 from hypersquirrel.util import html_from_url_with_headers
 
