@@ -1,5 +1,4 @@
-from commmons import html, strip_tags
-from commmons.url import get_host_url
+from commmons import html_from_url, get_host_url, strip_tags, html_to_string
 
 
 def get_post_id(post) -> str:
@@ -31,11 +30,11 @@ def get_thumbnail_url(post, host_url):
 
 
 def scrape(url):
-    root = html.from_url(url)
+    root = html_from_url(url)
     posts = root.xpath("//article[contains(@data-content, 'post-')]")
 
     title_div = root.xpath("//div[contains(@class, 'p-title')]")[0]
-    title = strip_tags(html_element_to_string(title_div))
+    title = strip_tags(html_to_string(title_div))
 
     host_url = get_host_url(url)
 
