@@ -1,5 +1,4 @@
-from commmons import html
-from commmons.url import get_host_url
+from commmons import html_from_url, get_host_url
 
 
 def _get_thumbnail_path(element):
@@ -16,7 +15,7 @@ def _get_title(element):
 
 def _s(url, prefix):
     host_url = get_host_url(url)
-    root = html.from_url(url)
+    root = html_from_url(url)
 
     for post in root.xpath("//div[contains(@class, 'col-md')]"):
         title = _get_title(post)
