@@ -1,4 +1,4 @@
-from commmons.hash import md5
+from commmons import md5
 from htmllistparse import htmllistparse, FileEntry
 
 
