@@ -1,4 +1,4 @@
-from commmons import html
+from commmons import html_from_url
 
 
 def get_title_and_url(div):
@@ -14,7 +14,7 @@ def get_thumbnail_url(div):
 
 
 def scrape_sbgx(url):
-    root = html.from_url(url)
+    root = html_from_url(url)
 
     for div in root.xpath("//div[@class='post-outer']"):
         title_and_url = get_title_and_url(div)
